@@ -24,14 +24,12 @@ from six.moves import tkinter_scrolledtext as scrolledtext
 from six.moves import tkinter_tkfiledialog as filedialog
 
 
-Abel_methods = ['basex', 'direct', 'hansenlaw', 'linbasex', 'onion_bordas',
-                'onion_peeling', 'rbasex', 'three_point', 'two_point']
+Abel_methods = ['basex', 'daun(nonneg)', 'direct', 'hansenlaw', 'linbasex',
+                'onion_bordas', 'onion_peeling', 'rbasex', 'three_point',
+                'two_point']
 
 Abel_methods_forward = ['basex', 'direct', 'hansenlaw', 'rbasex']
 
-Abel_methods_basis = ['basex', 'onion_peeling', 'three_point', 'two_point']
-                     # 'linbasex' and 'rbasex' can use disk cache but do not
-
 center_methods = ['com', 'convolution', 'gaussian', 'slice']
 
 
@@ -392,6 +390,10 @@ class PyAbel:  # (tk.Tk):
                     tk.END,
                     "\nbasex: first time calculation of the basis"
                     " functions may take a while ...")
+            elif self.method == "daun(nonneg)":
+                self.text.insert(
+                    tk.END,
+                    "\ndaun(reg=nonneg): calculations will take a while...")
             elif self.method == "direct":
                 self.text.insert(
                    tk.END,
@@ -404,22 +406,13 @@ class PyAbel:  # (tk.Tk):
                     self.AIM = abel.Transform(
                         self.IM, method=self.method, direction=self.fi,
                         transform_options=dict(return_Beta=True))
+                elif self.method == 'daun(nonneg)':
+                    self.AIM = abel.Transform(
+                        self.IM, method='daun', direction=self.fi,
+                        transform_options=dict(reg='nonneg'))
                 else:
-                    if self.method in Abel_methods_basis:
-                        basis_dir = 'bases'
-                        if not os.path.isdir(basis_dir):
-                            self.text.insert(tk.END,
-                                "\n(No '" + basis_dir + "' directory;"
-                                " bases sets will not be loaded/saved.)")
-                            self.text.see(tk.END)
-                            self.canvas.draw()
-                            basis_dir = None
-                    else:
-                        basis_dir = None
-
                     self.AIM = abel.Transform(
                         self.IM, method=self.method, direction=self.fi,
-                        transform_options=dict(basis_dir=basis_dir),
                         symmetry_axis=None)
             except Exception as e:
                 self.text.insert(tk.END, "\nAn error occurred:\n")
@@ -464,8 +457,8 @@ class PyAbel:  # (tk.Tk):
             self.radial, self.speed_dist, _ = self.AIM.distr.rIbeta()
         else:
             # speed distribution
-            self.radial, self.speed_dist = abel.tools.vmi.angular_integration(
-                                           self.AIM.transform)
+            self.radial, self.speed_dist = \
+                abel.tools.vmi.angular_integration_3D(self.AIM.transform)
 
         self.plt[1].axis("on")
         self.plt[1].plot(
